!/bin/bash

# For each *.tgz file find any "/configuration.xml or /config.xml files then
# we extract the files we found in the same directory structure the .tgz file
# had internally

# use find and read to avoid issues where the .tgz file has spaces

touch remove_created_dir.sh
echo "#!/bin/bash" > remove_created_dir.sh

find ./ -name "*.tgz" -print0 | while read -d $'\0' file
  do
    echo "Found $file"
    configs=$(tar -tf $file | grep -E '/configuration\.xml|/config\.xml')

# Use echo and read to avoid issues with spaces in the configuration name

    echo "$configs" | while read config
      do
       echo "    extracting $config" 
       tar -xf $file --directory ./ "$config"
# This gets eveything from the start of the line to the first /
       dirname=$(echo $config  | sed 's|\([^/]*/\).*$|\1|')
       echo "rm -fr $dirname"  >> remove_created_dir.sh

      done 

  done

# for each *.xml file we run xsltproc passing it the .xslt file then replacing the following characters;
#	%20	Space
#	%0A	<br>
#	%2F	/
#	%2C	,
# Then the output is written to the .html file

find ./ -iname "config*.xml" -print0 | while read -d $'\0' file 
  do
# This removes all the / characters from the filename
    newfile=${file////}
# This removes all characters past the last . in the filename then appends .html
    newfile=${newfile%.*}.html
# Remove the leading . from newfile
    newfile=${newfile:1}

    xsltproc vtserver_parser.xsl "$file" | sed 's/%20/ /g' | sed 's/%0A/<br>/g' | sed 's/%2F/\//g' | sed 's/%2C/,/g' > "$newfile"
    echo "Created $newfile from $file"

  done

chmod +x remove_created_dir.sh

PS3='Please enter your 1 to delete the XML and directories we created, 2 to leave them: '
options=("Delete" "Leave")
select opt in "${options[@]}"
do
  case $opt in
     "Delete")
       ./remove_created_dir.sh
       rm remove_created_dir.sh
       break;;
     "Leave")
       break;;
     *) echo "Invalid option $REPLY";;
  esac
done

